@@ -3,12 +3,12 @@ from collections import Counter
 
 from dataclasses import dataclass
 
-from expyct.base import Equals, MapBefore, Satisfies, Optional
+from expyct.base import Equals, MapBefore, Satisfies, Optional, BaseMatcher
 from expyct.base import Instance
 
 
-@dataclass
-class AllOrAny:
+@dataclass(repr=False, eq=False)
+class AllOrAny(BaseMatcher):
     """Mixin for matching a collection object by checking that all or at least
     one of its members are equal to given.
 
@@ -34,7 +34,7 @@ class AllOrAny:
         self.all = all
         self.any = any
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.all is not None:
             if not all(x == self.all for x in other):
                 return False
@@ -44,8 +44,8 @@ class AllOrAny:
         return True
 
 
-@dataclass
-class Length:
+@dataclass(repr=False, eq=False)
+class Length(BaseMatcher):
     """Mixin for matching a collection object by its length as the result of len()."""
 
     length: typing.Optional[int] = None
@@ -74,7 +74,7 @@ class Length:
         self.max_length = max_length
         self.non_empty = non_empty
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.length is not None:
             if not len(other) == self.length:
                 return False
@@ -90,8 +90,8 @@ class Length:
         return True
 
 
-@dataclass
-class Contains:
+@dataclass(repr=False, eq=False)
+class Contains(BaseMatcher):
     """Mixin matching a collection object by the containment of specified members."""
 
     superset_of: typing.Optional[typing.Collection] = None
@@ -111,7 +111,7 @@ class Contains:
         self.superset_of = superset_of
         self.subset_of = subset_of
 
-    def __eq__(self, other):
+    def _eq(self, other):
         if self.subset_of is not None:
             if isinstance(other, dict) and isinstance(self.subset_of, dict):
                 if not all(x in self.subset_of.items() for x in other.items()):
@@ -130,7 +130,7 @@ class Contains:
         return True
 
 
-@dataclass
+@dataclass(repr=False, eq=False)
 class Collection(
     Satisfies,
     Contains,
@@ -140,6 +140,7 @@ class Collection(
     Optional,
     MapBefore,
     AllOrAny,
+    BaseMatcher,
 ):
     """Match any object that is an instance of `typing.Collection`."""
 
@@ -194,32 +195,34 @@ class Collection(
         self.subset_of = subset_of
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not isinstance(other, typing.Collection):
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not Instance.__eq__(self, other):
+        if not Instance._eq(self, other):
             return False
-        if not Length.__eq__(self, other):
+        if not Length._eq(self, other):
             return False
-        if not Contains.__eq__(self, other):
+        if not Contains._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
-        if not AllOrAny.__eq__(self, other):
+        if not AllOrAny._eq(self, other):
             return False
         return True
 
 
-@dataclass
-class List(Satisfies, Contains, Length, Equals[list], Optional, MapBefore, AllOrAny, list):
+@dataclass(repr=False, eq=False)
+class List(
+    Satisfies, Contains, Length, Equals[list], Optional, MapBefore, AllOrAny, BaseMatcher, list
+):
     """Match any object that is an instance of `list`."""
 
     ignore_order: bool = False
@@ -243,7 +246,7 @@ class List(Satisfies, Contains, Length, Equals[list], Optional, MapBefore, AllOr
         satisfies: typing.Optional[typing.Callable[[typing.Any], bool]] = None,
         ignore_order: bool = False,
     ):
-        """ "Match any object that is an instance of `list`.
+        """Match any object that is an instance of `list`.
 
         Args:
             all : all members of collection must equal
@@ -275,28 +278,28 @@ class List(Satisfies, Contains, Length, Equals[list], Optional, MapBefore, AllOr
         self.satisfies = satisfies
         self.ignore_order = ignore_order
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not isinstance(other, list):
             return False
         if self.ignore_order:
             if not self._equals_ignore_order(self.equals, other):
                 return False
         else:
-            if not Equals.__eq__(self, other):
+            if not Equals._eq(self, other):
                 return False
-        if not Length.__eq__(self, other):
+        if not Length._eq(self, other):
             return False
-        if not Contains.__eq__(self, other):
+        if not Contains._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
-        if not AllOrAny.__eq__(self, other):
+        if not AllOrAny._eq(self, other):
             return False
         return True
 
@@ -309,8 +312,10 @@ class List(Satisfies, Contains, Length, Equals[list], Optional, MapBefore, AllOr
             return len(a) == len(b) and all(a.count(i) == b.count(i) for i in a)  # O(n * n)
 
 
-@dataclass
-class Tuple(Satisfies, Contains, Length, Equals[tuple], Optional, MapBefore, AllOrAny, tuple):
+@dataclass(repr=False, eq=False)
+class Tuple(
+    Satisfies, Contains, Length, Equals[tuple], Optional, MapBefore, AllOrAny, BaseMatcher, tuple
+):
     """Match any object that is an instance of `tuple`."""
 
     def __new__(cls, *args, **kwargs):
@@ -363,30 +368,32 @@ class Tuple(Satisfies, Contains, Length, Equals[tuple], Optional, MapBefore, All
         self.subset_of = subset_of
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not isinstance(other, tuple):
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not Length.__eq__(self, other):
+        if not Length._eq(self, other):
             return False
-        if not Contains.__eq__(self, other):
+        if not Contains._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
-        if not AllOrAny.__eq__(self, other):
+        if not AllOrAny._eq(self, other):
             return False
         return True
 
 
-@dataclass
-class Set(Satisfies, Contains, Length, Equals[set], Optional, MapBefore, AllOrAny, set):
+@dataclass(repr=False, eq=False)
+class Set(
+    Satisfies, Contains, Length, Equals[set], Optional, MapBefore, AllOrAny, BaseMatcher, set
+):
     """Match any object that is an instance of `set`."""
 
     def __new__(cls, *args, **kwargs):
@@ -439,30 +446,30 @@ class Set(Satisfies, Contains, Length, Equals[set], Optional, MapBefore, AllOrAn
         self.subset_of = subset_of
         self.satisfies = satisfies
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not isinstance(other, set):
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not Length.__eq__(self, other):
+        if not Length._eq(self, other):
             return False
-        if not Contains.__eq__(self, other):
+        if not Contains._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
-        if not AllOrAny.__eq__(self, other):
+        if not AllOrAny._eq(self, other):
             return False
         return True
 
 
-@dataclass
-class Dict(Satisfies, Contains, Length, Equals[dict], Optional, MapBefore, dict):
+@dataclass(repr=False, eq=False)
+class Dict(Satisfies, Contains, Length, Equals[dict], Optional, MapBefore, BaseMatcher, dict):
     """Match any object that is an instance of `dict`."""
 
     superset_of: typing.Optional[dict] = None
@@ -536,18 +543,18 @@ class Dict(Satisfies, Contains, Length, Equals[dict], Optional, MapBefore, dict)
         self.values_all = values_all
         self.values_any = values_any
 
-    def __eq__(self, other):
+    def _eq(self, other):
         try:
             other = MapBefore.map(self, other)
         except Exception:
             return False
         if other is None:
-            return Optional.__eq__(self, other)
+            return Optional._eq(self, other)
         if not isinstance(other, dict):
             return False
-        if not Equals.__eq__(self, other):
+        if not Equals._eq(self, other):
             return False
-        if not Length.__eq__(self, other):
+        if not Length._eq(self, other):
             return False
         if self.keys is not None:
             if not other.keys() == self.keys:
@@ -555,9 +562,9 @@ class Dict(Satisfies, Contains, Length, Equals[dict], Optional, MapBefore, dict)
         if self.values is not None:
             if not other.values() == self.values:
                 return False
-        if not Contains.__eq__(self, other):
+        if not Contains._eq(self, other):
             return False
-        if not Satisfies.__eq__(self, other):
+        if not Satisfies._eq(self, other):
             return False
         if self.keys_all is not None:
             if not all(x == self.keys_all for x in other.keys()):
